import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
var BASE_CLASS = 'sui-AtomInput-input';
var SIZES = {
  MEDIUM: 'm',
  SMALL: 's'
};
var ERROR_STATES = {
  ERROR: 'error',
  SUCCESS: 'success'
};

var Input =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(Input, _Component);

  function Input() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;

    _this.changeHandler = function (ev) {
      var onChange = _this.props.onChange;
      var value = ev.target.value;
      onChange(ev, {
        value: value
      });
    };

    _this.handleKeyDown = function (ev) {
      var _this$props = _this.props,
          onEnter = _this$props.onEnter,
          onEnterKey = _this$props.onEnterKey,
          onKeyDown = _this$props.onKeyDown;
      var value = ev.target.value;
      var key = ev.key;
      onKeyDown(ev, {
        value: value
      });
      if (key === onEnterKey) onEnter(ev, {
        value: value
      });
    };

    return _this;
  }

  var _proto = Input.prototype;

  _proto.getErrorStateClass = function getErrorStateClass(errorState) {
    if (errorState) return BASE_CLASS + "--" + ERROR_STATES.ERROR;
    if (errorState === false) return BASE_CLASS + "--" + ERROR_STATES.SUCCESS;
    return '';
  };

  _proto.getClassNames = function getClassNames(_ref) {
    var size = _ref.size,
        charsSize = _ref.charsSize,
        hideInput = _ref.hideInput,
        noBorder = _ref.noBorder,
        readOnly = _ref.readOnly,
        errorState = _ref.errorState;
    return cx(BASE_CLASS, BASE_CLASS + "-" + size, charsSize && BASE_CLASS + "--size", hideInput && BASE_CLASS + "--hidden", noBorder && BASE_CLASS + "--noBorder", readOnly && BASE_CLASS + "--readOnly", this.getErrorStateClass(errorState));
  };

  _proto.render = function render() {
    var _this$props2 = this.props,
        checked = _this$props2.checked,
        disabled = _this$props2.disabled,
        readOnly = _this$props2.readOnly,
        hideInput = _this$props2.hideInput,
        noBorder = _this$props2.noBorder,
        id = _this$props2.id,
        name = _this$props2.name,
        onBlur = _this$props2.onBlur,
        onFocus = _this$props2.onFocus,
        placeholder = _this$props2.placeholder,
        reference = _this$props2.reference,
        size = _this$props2.size,
        errorState = _this$props2.errorState,
        type = _this$props2.type,
        value = _this$props2.value,
        charsSize = _this$props2.charsSize,
        tabIndex = _this$props2.tabIndex,
        maxLength = _this$props2.maxLength,
        autoComplete = _this$props2.autoComplete;
    return React.createElement("input", {
      className: this.getClassNames({
        size: size,
        charsSize: charsSize,
        hideInput: hideInput,
        noBorder: noBorder,
        readOnly: readOnly,
        errorState: errorState
      }),
      tabIndex: tabIndex,
      checked: checked,
      disabled: disabled || readOnly,
      readOnly: readOnly,
      id: id,
      name: name,
      onChange: this.changeHandler,
      onFocus: onFocus,
      onBlur: onBlur,
      onKeyDown: this.handleKeyDown,
      placeholder: placeholder,
      ref: reference,
      type: type,
      value: value,
      size: charsSize,
      maxLength: maxLength,
      autoComplete: autoComplete
    });
  };

  return Input;
}(Component);

Input.defaultProps = {
  size: SIZES.MEDIUM,
  onEnterKey: 'Enter',
  tabIndex: -1,
  onKeyDown: function onKeyDown() {},
  onEnter: function onEnter() {},
  onChange: function onChange() {}
};
export default Input;
export { SIZES as inputSizes };